import * as react_jsx_runtime from 'react/jsx-runtime';
import * as react from 'react';
import * as xstate from 'xstate';
import { CheckedState, FormOptions } from '@react-dive-ui/checkbox-machine';

type CheckboxOptions = {
    id?: string;
    checkedState?: CheckedState;
    disabled?: boolean;
    form?: FormOptions;
    value?: string;
    onChange?: (checked: CheckedState) => void;
};
declare function useCheckbox(options?: CheckboxOptions): {
    state: {
        id: string;
        checkedState: CheckedState;
        disabled: boolean;
        value: string;
        form: FormOptions | null;
        status: xstate.StateValue;
    };
    apis: {
        check: () => void;
        setChecked: (checked: boolean) => void;
        setIndeterminate: () => void;
        setDisabled: (disabled: boolean) => void;
    };
    props: {
        controlProps: Omit<react.DetailedHTMLProps<react.ButtonHTMLAttributes<HTMLButtonElement>, HTMLButtonElement>, "ref">;
        labelProps: Omit<react.DetailedHTMLProps<react.LabelHTMLAttributes<HTMLLabelElement>, HTMLLabelElement>, "ref">;
        hiddenInputProps: Omit<react.DetailedHTMLProps<react.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>, "ref">;
    };
};

declare const Checkbox: {
    Provider: ({ children, ...options }: {
        children: react.ReactNode;
    } & CheckboxOptions) => react_jsx_runtime.JSX.Element;
    Control: react.ForwardRefExoticComponent<Omit<Omit<react.DetailedHTMLProps<react.ButtonHTMLAttributes<HTMLButtonElement>, HTMLButtonElement>, "ref"> & {
        ref?: ((instance: HTMLButtonElement | null) => void) | react.RefObject<HTMLButtonElement> | null | undefined;
    } & {
        [key: `data-${string}`]: string | boolean | undefined;
        asChild?: boolean | undefined;
        style?: react.CSSProperties | {
            [styleVariable: `--${string}`]: string | undefined;
        } | undefined;
    }, "ref"> & react.RefAttributes<HTMLButtonElement>>;
    Label: react.ForwardRefExoticComponent<Omit<Omit<react.DetailedHTMLProps<react.LabelHTMLAttributes<HTMLLabelElement>, HTMLLabelElement>, "ref"> & {
        ref?: ((instance: HTMLLabelElement | null) => void) | react.RefObject<HTMLLabelElement> | null | undefined;
    } & {
        [key: `data-${string}`]: string | boolean | undefined;
        asChild?: boolean | undefined;
        style?: react.CSSProperties | {
            [styleVariable: `--${string}`]: string | undefined;
        } | undefined;
    }, "ref"> & react.RefAttributes<HTMLLabelElement>>;
    HiddenInput: react.ForwardRefExoticComponent<Omit<Omit<react.DetailedHTMLProps<react.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>, "ref"> & {
        ref?: ((instance: HTMLInputElement | null) => void) | react.RefObject<HTMLInputElement> | null | undefined;
    } & {
        [key: `data-${string}`]: string | boolean | undefined;
        asChild?: boolean | undefined;
        style?: react.CSSProperties | {
            [styleVariable: `--${string}`]: string | undefined;
        } | undefined;
    }, "ref"> & react.RefAttributes<HTMLInputElement>>;
};

export { Checkbox, CheckboxOptions, useCheckbox };
